==> webHotfixV1.2.0_10-14.tar: icpdas/httpd/page/sys_rebootTimer.php <==

<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//===========================================
//== get and setting rebootTimer parameter ==
//===========================================

require_once("./class.php");

if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$interval = trim($_POST["interval"]);
	$enable = $_POST["enable"];

	//-- auto-run manage
	if($enable=="enable")
		$enable="enable";
	else
		$enable="disable";

	$proc_name = CommonData::$REBOOTT_EXE;
	$full_file_name = CommonData::$REBOOTT_DIR ."/" .$proc_name;
	//- php call php-script時，需要把「輸入/輸出」重導到別的地方，不可用std io，否則不會執行成功
	addUserProc("Reboot Timer", $full_file_name ." > /dev/null", "/usr/bin/killall -9 " .$proc_name, $full_file_name, $enable);
	getUserProcCgf($proc_list);
	setAutoRunFW($proc_list);

	//-- set vxsc configure into vxserver.ini
	setRebootTimerInfo($interval);
	echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";

	//-- Start/Stop firmware
	$n = count($proc_list);
	for($i=0; $i<$n; $i++)
	{
		if($proc_list[$i]["exec"] == $full_file_name)
		{
			//enable--> restart FW
			if($enable=="enable")
			{
				shell_exec($proc_list[$i]["stop"]);
				pclose(popen($proc_list[$i]["start"] ." &", "r"));//put into backgroud, or php will be block
				echo "<div align=\"center\"><font color=\"#cc0000\">Execute ".$proc_list[$i]["name"]." successfully</font><br>\n";
				break;
			}else
			{
				shell_exec($proc_list[$i]["stop"]);
				echo "<div align=\"center\"><font color=\"#cc0000\">Stop ".$proc_list[$i]["name"]." successfully</font><br>\n";
				break;
			}
		}
	}
}

//READ INFORMATION
getRebootTimerInfo($interval, $enable, $alive)
?>

	<br>
	<form method="post" name="ethernet"><br>
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="2" bgcolor="#ffcc99">Reboot Timer (Reboot system automatically)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Interval Time</td>
			<td ><input size="20" name="interval" value="<?php echo $interval;?>" >hours<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Enable Funcion</td>
			<td ><input size="20" name="enable" type="checkbox" value="enable"<?php if($enable=="enable") echo "checked";?> >Enable <br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Alive</td>
			<?php
				if($alive == "true")
				{
					echo '<td bgcolor="#33ff33">True</td>'."\n";
				}else
				{
					echo '<td bgcolor="#cccccc">False</td>'."\n";
				}
			?>
		</tr>

		<tr align="center">
			<td colspan="2"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		<tr>
			<td colspan="2">
			(1):This function will run immediately after you press "Modify" button<br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>
</body>
</html>

==> webHotfixV1.3.0_2015-08-25.tar: icpdas/httpd/page/sys_rebootTimer.php <==

<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//===========================================
//== get and setting rebootTimer parameter ==
//===========================================

require_once("./class.php");

if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$interval = trim($_POST["interval"]);
	$rbHour = trim($_POST["rbHour"]);
	$rbMinute = trim($_POST["rbMinute"]);
	$enable = $_POST["enable"];

	//-- auto-run manage
	if($enable=="enable")
		$enable="enable";
	else
		$enable="disable";

	$proc_name = CommonData::$REBOOTT_EXE;
	$full_file_name = CommonData::$REBOOTT_DIR ."/" .$proc_name;
	//- php call php-script時，需要把「輸入/輸出」重導到別的地方，不可用std io，否則不會執行成功
	addUserProc("Reboot Timer", $full_file_name ." > /dev/null", "/usr/bin/killall -9 " .$proc_name, $full_file_name, $enable);
	getUserProcCgf($proc_list);
	setAutoRunFW($proc_list);

	//-- set vxsc configure into vxserver.ini
	setRebootTimerInfo($rbHour, $rbMinute);
	echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";

	//-- Start/Stop firmware
	$n = count($proc_list);
	for($i=0; $i<$n; $i++)
	{
		if($proc_list[$i]["exec"] == $full_file_name)
		{
			//enable--> restart FW
			if($enable=="enable")
			{
				shell_exec($proc_list[$i]["stop"]);
				pclose(popen($proc_list[$i]["start"] ." &", "r"));//put into backgroud, or php will be block
				echo "<div align=\"center\"><font color=\"#cc0000\">Execute ".$proc_list[$i]["name"]." successfully</font><br>\n";
				break;
			}else
			{
				shell_exec($proc_list[$i]["stop"]);
				echo "<div align=\"center\"><font color=\"#cc0000\">Stop ".$proc_list[$i]["name"]." successfully</font><br>\n";
				break;
			}
		}
	}
}

//READ INFORMATION
getRebootTimerInfo($rbHour, $rbMinute, $enable, $alive, $version)
?>

	<br>
	<form method="post" name="ethernet"><br>
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="2" bgcolor="#ffcc99">Reboot Timer (Reboot system automatically)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Reboot Time (everyday)</td>
			<td >
			<input size="2" name="rbHour" value="<?php echo $rbHour;?>" maxlength=2 onkeyup="this.value=this.value.replace(/[^0-9]/g,'')" >
			:
			<input size="2" name="rbMinute" value="<?php echo $rbMinute;?>" maxlength=2 onkeyup="this.value=this.value.replace(/[^0-9]/g,'')" >
			(hour:minute)
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Enable Funcion</td>
			<td ><input size="20" name="enable" type="checkbox" value="enable"<?php if($enable=="enable") echo "checked";?> >Enable <br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Alive</td>
			<?php
				if($alive == "true")
				{
					echo '<td bgcolor="#33ff33">True</td>'."\n";
				}else
				{
					echo '<td bgcolor="#cccccc">False</td>'."\n";
				}
			?>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Firmware Version</td>
			<td ><?php echo $version;?></td>
		</tr>

		<tr align="center">
			<td colspan="2"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		<tr>
			<td colspan="2">
			(1):This function will run immediately after you press "Modify" button<br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>
</body>
</html>
